@@ -20,6 +20,7 @@ from ccinput.utilities import (
     has_dispersion_parameters,
     warn,
     indexify,
+    get_charge_mult_from_name,
 )
 from ccinput.constants import ATOMIC_NUMBER, SYN_SOFTWARE, BASIS_SET_EXCHANGE_KEY
 
@@ -111,27 +112,7 @@ class Calculation:
                     f"Cannot parse the charge and multiplicity from the file name: no file given"
                 )
 
-            if "trication" in file:
-                self.charge = 3
-            elif "dication" in file:
-                self.charge = 2
-            elif "cation" in file:
-                self.charge = 1
-            elif "trianion" in file:
-                self.charge = -3
-            elif "dianion" in file:
-                self.charge = -2
-            elif "anion" in file:
-                self.charge = -1
-            elif "neutral" in file:
-                self.charge = 0
-
-            if "radical" in file or "doublet" in file:
-                self.multiplicity = 2
-            elif "triplet" in file:
-                self.multiplicity = 3
-            elif "singlet" in file:
-                self.multiplicity = 1
+            self.charge, self.multiplicity = get_charge_mult_from_name(file)
 
         self.verify_charge_mult()
         self.constraints = constraints
@@ -149,7 +130,7 @@ class Calculation:
         else:
             self.aux_name = aux_name
         self.header = header
-        self.driver = driver
+        self.driver = driver.lower()
         self.kwargs = kwargs
 
     def verify_charge_mult(self):
@@ -193,10 +174,10 @@ class Parameters:
         custom_basis_sets="",
         d3=False,
         d3bj=False,
+        trust_me=False,
         **kwargs,
     ):
-
-        self.solvent = get_abs_solvent(solvent)
+        self.solvent = get_abs_solvent(solvent, trust_me=trust_me)
         if self.solvent != "":
             self.solvation_model = solvation_model.lower()
             self.solvation_radii = solvation_radii.lower()
@@ -229,7 +210,7 @@ class Parameters:
         self.theory_level = get_theory_level(self.method)
 
         if self.theory_level not in ["semiempirical", "xtb", "special"]:
-            self.basis_set = get_abs_basis_set(basis_set)
+            self.basis_set = get_abs_basis_set(basis_set, trust_me=trust_me)
         else:
             self.basis_set = ""
 
@@ -258,8 +239,9 @@ class Parameters:
 
         dict_cbs = {}
 
-        for entry in custom_basis_sets.split(";"):
-            if entry.strip() == "":
+        for _entry in custom_basis_sets.split(";"):
+            entry = _entry.replace(" ", "")
+            if entry == "":
                 continue
             sentry = entry.split("=")
 
@@ -278,7 +260,7 @@ class Parameters:
             if bs_index in BASIS_SET_EXCHANGE_KEY:
                 bs_keyword = BASIS_SET_EXCHANGE_KEY[bs_index]
             else:
-                bs_keyword = get_abs_basis_set(bs_str)
+                bs_keyword = get_abs_basis_set(bs_str, trust_me=trust_me)
 
             dict_cbs[el] = bs_keyword
 
