@@ -697,6 +697,20 @@ class XtbTests(InputTests):
 
         self.assertTrue(self.is_equivalent(REF, xtb.command))
 
+    def test_gfn1_method(self):
+        params = {
+            "type": "Single-Point Energy",
+            "method": "gfn0",
+            "file": "ethanol.xyz",
+            "software": "xtb",
+        }
+
+        xtb = self.generate_calculation(**params)
+
+        REF = "xtb ethanol.xyz --gfn 0"
+
+        self.assertTrue(self.is_equivalent(REF, xtb.command))
+
     def test_gfn2(self):
         params = {
             "type": "Single-Point Energy",
@@ -725,6 +739,20 @@ class XtbTests(InputTests):
 
         self.assertTrue(self.is_equivalent(REF, xtb.command))
 
+    def test_gfnff_method(self):
+        params = {
+            "type": "Single-Point Energy",
+            "file": "ethanol.xyz",
+            "software": "xtb",
+            "method": "gfnff",
+        }
+
+        xtb = self.generate_calculation(**params)
+
+        REF = "xtb ethanol.xyz --gfnff"
+
+        self.assertTrue(self.is_equivalent(REF, xtb.command))
+
     def test_unavailable_calc_type(self):
         params = {
             "type": "TS Optimisation",
