@@ -37,11 +37,12 @@ SOFTWARE_CLASSES = {
     "orca": OrcaCalculation,
     "xtb": XtbCalculation,
     "pysis": PysisDriver,
+    "pysisyphus": PysisDriver,
 }
 
 
 def process_calculation(calc):
-    if calc.driver == "none":
+    if calc.driver in ["none", None, ""] or calc.driver == calc.parameters.software:
         cls = SOFTWARE_CLASSES[calc.parameters.software](calc)
     else:
         cls = SOFTWARE_CLASSES[calc.driver](calc)
@@ -80,9 +81,9 @@ def generate_calculation(
     header="File created by ccinput",
     file=None,
     driver="none",
+    trust_me=False,
     **kwargs,
 ):
-
     if software is None:
         raise InvalidParameter("Specify a software package to use")
 
@@ -97,10 +98,7 @@ def generate_calculation(
     abs_software = get_abs_software(software)
 
     if method is None:
-        if abs_software == "xtb":
-            method = "gfn2-xtb"
-        else:
-            raise InvalidParameter("Specify a calculation method")
+        raise InvalidParameter("Specify a calculation method")
 
     calc_type = get_abs_type(type)
 
@@ -117,6 +115,7 @@ def generate_calculation(
         custom_basis_sets,
         d3,
         d3bj,
+        trust_me,
         **kwargs,
     )
 
@@ -355,6 +354,12 @@ def get_parser():
         help="Use filenames to assign the charge and multiplicity",
     )
 
+    parser.add_argument(
+        "--trust_me",
+        action="store_true",
+        help="Unknown values will be accepted as given",
+    )
+
     dispersion_group = parser.add_mutually_exclusive_group()
 
     dispersion_group.add_argument(
@@ -403,8 +408,9 @@ def get_parser():
     )
     parser.add_argument(
         "--driver",
-        choices=["none", "pysis"],
+        choices=["none", "ORCA", "pysis"],
         default="none",
+        type=str.lower,
         help="Specify a computation driver other than the calculation package",
     )
     parser.add_argument(
@@ -524,6 +530,7 @@ def get_input_from_args(args, default_params=None):
         "charge": args.charge,
         "multiplicity": args.mult,
         "parse_name": args.parse_name,
+        "trust_me": args.trust_me,
         "d3": args.d3,
         "d3bj": args.d3bj,
         "aux_name": args.aux_name,
